#ifndef RHC_OID_H_GUARD
#define RHC_OID_H_GUARD

#include <net-snmp/net-snmp-config.h>
#include <net-snmp/net-snmp-includes.h>
#include <net-snmp/agent/net-snmp-agent-includes.h>

/* SNMP OIDs we need to know about */
extern oid snmp_trap[];
extern size_t snmp_trap_len;

/* Cluster traps */
#define RHC_TRAPS(X) \
	X(ConfigVersion,               1, 3, 6, 1, 4, 1, 2312, 8, 0,  1 ) \
	X(QuorumState,                 1, 3, 6, 1, 4, 1, 2312, 8, 0,  2 ) \
	X(NodeState,                   1, 3, 6, 1, 4, 1, 2312, 8, 0,  3 ) \
	X(ServiceState,                1, 3, 6, 1, 4, 1, 2312, 8, 0,  4 )

/* Objects and tables */
#define RHC_OIDS(X) \
	/* Objects */                                                     \
	X(MIBVersion,                  1, 3, 6, 1, 4, 1, 2312, 8, 1,  1 ) \
	X(ClusterName,                 1, 3, 6, 1, 4, 1, 2312, 8, 2,  1 ) \
	X(ClusterStatusCode,           1, 3, 6, 1, 4, 1, 2312, 8, 2,  2 ) \
	X(ClusterStatusDesc,           1, 3, 6, 1, 4, 1, 2312, 8, 2,  3 ) \
	X(ClusterVotesNeededForQuorum, 1, 3, 6, 1, 4, 1, 2312, 8, 2,  4 ) \
	X(ClusterVotes,                1, 3, 6, 1, 4, 1, 2312, 8, 2,  5 ) \
	X(ClusterQuorate,              1, 3, 6, 1, 4, 1, 2312, 8, 2,  6 ) \
	X(ClusterNodesNum,             1, 3, 6, 1, 4, 1, 2312, 8, 2,  7 ) \
	X(ClusterNodesNames,           1, 3, 6, 1, 4, 1, 2312, 8, 2,  8 ) \
	X(ClusterAvailNodesNum,        1, 3, 6, 1, 4, 1, 2312, 8, 2,  9 ) \
	X(ClusterAvailNodesNames,      1, 3, 6, 1, 4, 1, 2312, 8, 2, 10 ) \
	X(ClusterUnavailNodesNum,      1, 3, 6, 1, 4, 1, 2312, 8, 2, 11 ) \
	X(ClusterUnavailNodesNames,    1, 3, 6, 1, 4, 1, 2312, 8, 2, 12 ) \
	X(ClusterServicesNum,          1, 3, 6, 1, 4, 1, 2312, 8, 2, 13 ) \
	X(ClusterServicesNames,        1, 3, 6, 1, 4, 1, 2312, 8, 2, 14 ) \
	X(ClusterRunningServicesNum,   1, 3, 6, 1, 4, 1, 2312, 8, 2, 15 ) \
	X(ClusterRunningServicesNames, 1, 3, 6, 1, 4, 1, 2312, 8, 2, 16 ) \
	X(ClusterStoppedServicesNum,   1, 3, 6, 1, 4, 1, 2312, 8, 2, 17 ) \
	X(ClusterStoppedServicesNames, 1, 3, 6, 1, 4, 1, 2312, 8, 2, 18 ) \
	X(ClusterFailedServicesNum,    1, 3, 6, 1, 4, 1, 2312, 8, 2, 19 ) \
	X(ClusterFailedServicesNames,  1, 3, 6, 1, 4, 1, 2312, 8, 2, 20 ) \
	X(ClusterConfigVersion,        1, 3, 6, 1, 4, 1, 2312, 8, 2, 21 ) \
	/* Tables */                                                      \
	X(NodesTable,                  1, 3, 6, 1, 4, 1, 2312, 8, 3,  1 ) \
	X(ServicesTable,               1, 3, 6, 1, 4, 1, 2312, 8, 3,  2 )



#define RHC_TRAPS_DEFINE(_NAME, ...) \
	oid rhc##_NAME##_trap[] = { __VA_ARGS__ };               \
	size_t rhc##_NAME##_len = OID_LENGTH(rhc##_NAME##_trap);

#define RHC_OIDS_DEFINE(_NAME, ...) \
	oid rhc##_NAME##_oid[] = { __VA_ARGS__ };               \
	size_t rhc##_NAME##_len = OID_LENGTH(rhc##_NAME##_oid);


/* declare in-situ as it was here verbatim */

#define RHC_TRAPS_DECLARE(_NAME, ...) \
	extern oid rhc##_NAME##_trap[]; extern size_t rhc##_NAME##_len;

#define RHC_OIDS_DECLARE(_NAME, ...) \
	extern oid rhc##_NAME##_oid[]; extern size_t rhc##_NAME##_len;

RHC_TRAPS(RHC_TRAPS_DECLARE)
RHC_OIDS(RHC_OIDS_DECLARE)

#undef RHC_TRAPS_DECLARE
#undef RHC_OIDS_DECLARE

#endif
